@@ -1,43 +1,35 @@
 /*
- Copyright 2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
- Author: Daniel Vrátil <daniel.vratil@kdab.com>
+    SPDX-FileCopyrightText: 2017 Klarälvdalens Datakonsult AB a KDAB Group company info@kdab.com
+    SPDX-FileContributor: Daniel Vrátil <daniel.vratil@kdab.com>
 
- This library is free software; you can redistribute it and/or
- modify it under the terms of the GNU Lesser General Public
- License as published by the Free Software Foundation; either
- version 2.1 of the License, or (at your option) any later version.
-
- This library is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- Lesser General Public License for more details.
-
- You should have received a copy of the GNU Lesser General Public
- License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include <purpose/pluginbase.h>
 
-#include <KPluginFactory>
 #include <KLocalizedString>
+#include <KPluginFactory>
 
-#include <QStandardPaths>
-#include <QProcess>
-#include <QDesktopServices>
-#include <QUrlQuery>
 #include <QDebug>
+#include <QDesktopServices>
+#include <QJsonArray>
+#include <QProcess>
+#include <QStandardPaths>
+#include <QUrl>
+#include <QUrlQuery>
 
 EXPORT_SHARE_VERSION
 
-namespace {
-
+namespace
+{
 class EmailJob : public Purpose::Job
 {
     Q_OBJECT
 public:
     explicit EmailJob(QObject *parent = nullptr)
         : Purpose::Job(parent)
-    {}
+    {
+    }
 
     void start() override
     {
@@ -51,10 +43,8 @@ public:
 
         auto xdgmimeProc = new QProcess(this);
         xdgmimeProc->setProgram(xdgmime);
-        xdgmimeProc->setArguments({ QStringLiteral("query"), QStringLiteral("default"),
-                                    QStringLiteral("x-scheme-handler/mailto") });
-        connect(xdgmimeProc, static_cast<void(QProcess::*)(int,QProcess::ExitStatus)>(&QProcess::finished),
-                this, &EmailJob::xdgMimeFinished);
+        xdgmimeProc->setArguments({QStringLiteral("query"), QStringLiteral("default"), QStringLiteral("x-scheme-handler/mailto")});
+        connect(xdgmimeProc, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, &EmailJob::xdgMimeFinished);
         xdgmimeProc->start();
     }
 
@@ -66,7 +56,7 @@ public:
             return;
         }
 
-        const auto proc = qobject_cast<QProcess*>(sender());
+        const auto proc = qobject_cast<QProcess *>(sender());
         const auto mailService = proc->readAllStandardOutput();
         qDebug() << "Default mailto handler:" << mailService;
         // Thunderbird is a special snowflake and cannot handle attachments via
@@ -114,7 +104,7 @@ public:
 
         const auto urls = data().value(QStringLiteral("urls")).toArray();
         QStringList attachments;
-        QStringList args = QStringList{ QStringLiteral("-compose")};
+        QStringList args = QStringList{QStringLiteral("-compose")};
         QString message;
         for (const auto &att : urls) {
             QUrl url(att.toString());
@@ -125,7 +115,7 @@ public:
             }
         }
 
-        message +=(QStringLiteral("attachment='%1'").arg(attachments.join(QStringLiteral(","))));
+        message += (QStringLiteral("attachment='%1'").arg(attachments.join(QLatin1Char(','))));
         args.append(message);
 
         if (!QProcess::startDetached(tb, args)) {
@@ -134,7 +124,6 @@ public:
         }
         emitResult();
     }
-
 };
 
 }
@@ -145,7 +134,8 @@ class Q_DECL_EXPORT EmailPlugin : public Purpose::PluginBase
 public:
     EmailPlugin(QObject *p, const QVariantList &)
         : Purpose::PluginBase(p)
-    {}
+    {
+    }
 
     Purpose::Job *createJob() const override
     {
